*******
SpecSim
*******

SpecSim is a python package for quick simulations of multi-fiber spectrograph
response.  For a quick introduction, browse the `examples notebook
<https://github.com/desihub/specsim/blob/master/docs/nb/SimulationExamples.ipynb>`__
or try one of the :doc:`command-line programs <cmdline>`.

.. toctree::
    :maxdepth: 2

    install.rst
    guide.rst
    config.rst
    cmdline.rst
    output.rst
    fiberloss.rst
    history.rst
    changes.rst
    api.rst
